function [W_LSQMID, Wcand_1, min_idx_1, QMI_list_1] = ...
	LSQMID_SDR(X,Y,dz,sigma_list,lambda_list,b, Max_Trial)

[dx n] = size(X);
[dy ny] = size(Y);
if n~=ny
    error('numbers of samples of x and y must be the same!!!')
end

if nargin < 3
    error('Please specify the dimension of the target space!!!')
end;

if nargin < 4 || isempty(sigma_list)
    sigma_list = [0.1, 0.25, 0.5, 0.75, 1.0, 1.25, 1.5];
end;

if nargin < 5 || isempty(lambda_list)
    lambda_list = logspace(-2, 0, 9);
end;

if nargin < 6 || isempty(b)
    b=200; 
end;

if nargin < 7 || isempty(Max_Trial)
    Max_Trial = 10; 
end;

W_list = cell(Max_Trial, 1);
for ii = [1:Max_Trial]
    Ww = randn(dx,dx); 
    Ww = Ww'*Ww;
    [Ww V D] = svd(Ww);
    W = Ww(1:dz,:);
    W_list{ii, 1} = W;
end
%%%%%%%%%%%%%%%%%%%%%%%

sigma_list2 = [0.025: 0.025: 0.95];	%sigma list for LSQMI estimation
lambda_list2 = logspace(-2, 0, 9);	%lambda list for LSQMI estimation

b = min(n,b);
FOLDNUM = 5;
cv_split = floor( (0:n-1)*FOLDNUM./n)+1;

ww = randperm(n);
cindz = ww(1:b);
cindy = cindz;

cv_index = randperm(n);

[Cy, YC_dist, CyCy_dist] = Y_gen(Y, cindy);
Xl3d = permute(repmat(X, [1, 1, b]), [3 1 2]);    %[dx n b] --permute--> [b dx n]

sigma_dz = ones(dz, 1)*sigma_list(1);
lambda_dz = ones(dz, 1)*lambda_list(1);

%tuning parameter list of each initial solution
s_list_1 = zeros(1, Max_Trial);
l_list_1 = zeros(1, Max_Trial);
ss_list_1 = zeros(dz, Max_Trial);
ll_list_1 = zeros(dz, Max_Trial);
QMI_list_1 = zeros(Max_Trial, 1);
Wcand_1 = cell(Max_Trial, 1);

Ib = eye(b,b);

cv_mod = 10;		%for changing the frequency of cross-validation, e.g., once every X update 
iter = 200;			%how many update iterations

for Initial =  1:Max_Trial
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
	W = W_list{Initial, 1};
	W_tmp = W;
	for iterate = 1 : iter	
		if mod(iterate-1, cv_mod) == 0
			W = orthogonalizerows(W, dz, dx);	%orthogonalize the matrix
			CVinLSQMID;							%do cross-validation
		end;
				
		LSQMID_solve;   						%estimate derivative of QMI
					
		W = W + dQMI./F3;						%gradient formulation is faster because F1 and F2 are not needed.
		%W = (F1 - F2)./F3;
		
		if norm(W - W_tmp, 'fro') <= 0.00001	%stopping criteria
			break;	
		end
		
		W_tmp = W;								%save old value
	end		

	%save these value first
	W = orthogonalizerows(W, dz, dx);			%orthogonalize the matrix
	CVinLSQMI;									%do CV for LSQMI method
	LSQMI_solve_cv;								%estimate QMI by LSQMI
    QMI_list_1(Initial) = -QMI_A;				%take its negative because the below code is for minimization
	
	s_list_1(Initial) = sigma;
	l_list_1(Initial) = lambda;
    ss_list_1(:, Initial) = sigma_dz;
    ll_list_1(:, Initial) = lambda_dz;
    Wcand_1{Initial} = W;
	%%%%%%%%%%%%%%%%%%%%%
end;

%select the best value's sigma and lambda
[tmp, tmp_1] = min(QMI_list_1);
sigma = s_list_1(tmp_1);
lambda = l_list_1(tmp_1);

%recompute QMI using the above sigma and lambda
for Initial =  1:Max_Trial
	W = Wcand_1{Initial};
	LSQMI_solve_cv_FINAL;
    QMI_list_1(Initial) = -QMI_A;
end

%choose the best solution which minimizes the negative QMI estimated by LSQMI
[QMI_ans_1, min_idx_1] = min(QMI_list_1);
W_LSQMID = Wcand_1{min_idx_1};

end
