function demo_LSQMID_SDR()

dataset = -2;		%dataset number
n_tr = 100;			%training samples
dx = 3;				%input dimension
Max_Trial = 5;		%number of initial solutions

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%seed = 1;			%random seed
%RandStream.setGlobalStream(RandStream('mt19937ar','Seed',seed));	

switch dataset
	case -2
		n = n_tr/2;
		X1= randn(dx,n);
		X2= randn(dx,n);
		X1(1,:) = X1(1,:) + repmat([-3],[1 n]);
		X2(1,:) = X2(1,:) + repmat([ 3],[1 n]);
		RAW_X=[X1 X2];
		RAW_Y=[-ones(1,n) ones(1,n)];
		dz = 1;
		W_opt = zeros(1,dx);
		W_opt(1,1) = 1;
	case -1	%simple sine with additive Gaussian noise
		RAW_X = (-1 + 2*rand(dx,n_tr)*2)*10;
		RAW_Y = sin(RAW_X(1,:)/10*pi) + randn(1,n_tr)*0.25; 
		W_opt = zeros(1,dx);
		W_opt(1,1) = 1;
		dz = 1;
	case 0	%simple quadratic with additive Gaussian noise
		RAW_X = randn(dx, n_tr);
		RAW_Y = -RAW_X(1,:).^2 + randn(1,n_tr)*0.50; 
		W_opt = zeros(1, dx);
		W_opt(1,1) = 1;
		dz = 1;
	case 1	%dataset A (additive Gamma noise)
		RAW_X = randn(dx, n_tr);
		RAW_Y = exp( -(RAW_X(1,:) + RAW_X(2,:)).^2/(2*0.5^2) ) + gamrnd(0.25,0.25, 1, n_tr); 
		W_opt = zeros(1, dx);
		W_opt(1,1) = 1/sqrt(2);
		W_opt(1,2) = 1/sqrt(2);
		dz = 1;
	case 2	%dataset B (additive Gamma noise)
		RAW_X = rand(dx, n_tr)*2-1;
		Z = (RAW_X(1,:) + 2*RAW_X(2,:))/sqrt(5);
		RAW_Y = Z.*sin(Z) - gamrnd(0.25,0.5, 1, n_tr); 
		W_opt = zeros(1, dx);
		W_opt(1,1) = 1;
		W_opt(1,2) = 2;
		W_opt = W_opt./repmat(sqrt(sum(W_opt.^2,2)), 1, dx);
		dz = 1;		
	case 3	%dataset C (additive Gamma noise)
		RAW_X = -1 + 2*rand(dx, n_tr);
		RAW_Y = (RAW_X(1,:) .* RAW_X(2,:))/sqrt(2) - gamrnd(0.25, 0.5, [1, n_tr]);
		W_opt = zeros(2, dx);
		W_opt(1,1) = 1;
		W_opt(2,2) = 1;
		dz = 2;             
	case 4	%dataset D (multiplicative Gaussian noise)
		RAW_X = laprnd(0.0,0.5,dx, n_tr);
		RAW_Y = since(pi/2*RAW_X(1,:)) + RAW_X(2,:).*randn( [1, n_tr])*0.50;
		W_opt = zeros(1, dx);
		W_opt(1,1) = 1;
		W_opt(2,2) = 1;
		W_opt = W_opt./repmat(sqrt(sum(W_opt.^2,2)), 1, dx);
		dz = 2;              
end
%standardize data

xscale = std(RAW_X, 0, 2); %std of each dim
yscale = std(RAW_Y, 0, 2); %std of each dim
xmean = mean(RAW_X, 2); %mean of each dim
ymean = mean(RAW_Y, 2); %mean of each dim
X_tr = (RAW_X - repmat(xmean, [1, n_tr]))./repmat(xscale, [1, n_tr]);
Y_tr = (RAW_Y - repmat(ymean, [1, n_tr]))./repmat(yscale, [1, n_tr]);  

fprintf('Dataset %d, True W:\n', dataset);
disp(W_opt);
tic;
%RandStream.setGlobalStream(RandStream('mt19937ar','Seed',seed));
W = LSQMID_SDR(X_tr, Y_tr, dz, [], [], [], Max_Trial);
fprintf('DR error: %0.3f, time(s) %0.3f, estimated W:\n', norm(W'*W - W_opt'*W_opt,'fro'), toc);
disp(W);

W_length = 3;
figure(1);
clf; hold on;
scatter3(X_tr(1,:), X_tr(2,:), Y_tr, 80, Y_tr, 'filled', 'MarkerEdgeColor','k');
plot([-W(1) W(1)]*W_length, [-W(2) W(2)]*W_length, 'k-', 'LineWidth', 4);
xlabel('x^{(1)}');
ylabel('x^{(2)}');
zlabel('y');
title('Data and estimated subspace')
if dataset ~= -2
	colormap(jet); c = colorbar; 	title(c, 'y');
end
set(gca, 'fontsize', 15);

Z = W*X_tr;
if dataset <= 2
	figure(2);
	clf; hold on; 
	%plot(Z, Y_tr, '.b', 'MarkerSize', 18);
	scatter(Z, Y_tr, 80, Y_tr, 'filled', 'MarkerEdgeColor','k');
	xlabel('z = Wx');
	ylabel('y');
	title('Data after projection')
	colormap(jet);	cc = colorbar;	title(cc, 'y');
	set(gca, 'fontsize', 15);
else
	figure(2);
	clf; hold on; 
	scatter3(Z(1,:), Z(2,:), Y_tr, 80, Y_tr, 'filled', 'MarkerEdgeColor', 'k');
	xlabel('z^{(1)}');
	ylabel('z^{(2)}');
	zlabel('y');
	title('Data after projection')
	colormap(jet);	cc = colorbar;	title(cc, 'y');
	set(gca, 'fontsize', 15);
end

end
